==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_oc_va.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=oc_va
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'Adreiça de vòstre sit', # MODIF
	'form_pet_aucune_signature' => 'Ges de signatura correspònd pas a aqueu còde...', # MODIF
	'form_pet_confirmation' => 'Vougatz confirmar vòstra signatura:',
	'form_pet_deja_signe' => 'Avètz ja signat aqueu tèxt.',
	'form_pet_envoi_mail_confirmation' => 'Aüra recebretz un e-mail de confirmacion. Per validar vòstra signatura, chau vesitar l’adreiça web mençonaa per aquest corrier.', # MODIF
	'form_pet_mail_confirmation' => 'Bonjorn,

avètz demandat de signar la peticion:
@titre@.

Avètz fornias las informacions seguentas:
    Nom: @nom_email@
    Sit: @nom_site@ - @url_site@


IMPORTANT...
Per validar vòstra signatura, sufís de vos connectar a 
 l’adreiça çai sos (senon se regetarà
vòstra demanda): 
    @url@


Mercé per vòstra participacion
',
	'form_pet_nom_site2' => 'Nom de vòstre sit web', # MODIF
	'form_pet_probleme_technique' => 'Problèma tecnic, las signaturas son temporàriament arrestaas.',
	'form_pet_signature_validee' => 'Vòstra signatura es validaa. Mercé!',
	'form_pet_site_deja_enregistre' => 'Ja aqueu sit es registrat',
	'form_pet_url_invalide' => 'L’URL qu’avètz indicaa es pas valida.',
	'form_pet_votre_email' => 'Vòstra adreiça e-mail',
	'form_pet_votre_nom' => 'Vòstre nom o pseudonim', # MODIF
	'form_pet_votre_site' => 'Se tenètz un sit, o poètz marcar çai sos',

	// I
	'info_adresse_email' => 'ADREIÇA E-MAIL:',
	'info_site_web' => 'SIT WEB:',

	// L
	'lien_reponse_article' => 'Respònsa a l’article'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_oc_va.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=oc_va
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Activar la peticion',
	'bouton_radio_pas_petition' => 'Ges de peticion',
	'bouton_radio_petition_activee' => 'Peticion activaa',
	'bouton_radio_supprimer_petition' => 'Suprimir la peticion',

	// F
	'form_pet_adresse_site' => 'Adreiça de vòstre sit', # MODIF
	'form_pet_aucune_signature' => 'Ges de signatura correspònd pas a aqueu còde...', # MODIF
	'form_pet_confirmation' => 'Vougatz confirmar vòstra signatura:',
	'form_pet_deja_signe' => 'Avètz ja signat aqueu tèxt.',
	'form_pet_envoi_mail_confirmation' => 'Aüra recebretz un e-mail de confirmacion. Per validar vòstra signatura, chau vesitar l’adreiça web mençonaa per aquest corrier.', # MODIF
	'form_pet_mail_confirmation' => 'Bonjorn,

avètz demandat de signar la peticion:
@titre@.

Avètz fornias las informacions seguentas:
    Nom: @nom_email@
    Sit: @nom_site@ - @url_site@


IMPORTANT...
Per validar vòstra signatura, sufís de vos connectar a 
 l’adreiça çai sos (senon se regetarà
vòstra demanda): 
    @url@


Mercé per vòstra participacion
',
	'form_pet_nom_site2' => 'Nom de vòstre sit web', # MODIF
	'form_pet_probleme_technique' => 'Problèma tecnic, las signaturas son temporàriament arrestaas.',
	'form_pet_signature_validee' => 'Vòstra signatura es validaa. Mercé!',
	'form_pet_site_deja_enregistre' => 'Ja aqueu sit es registrat',
	'form_pet_url_invalide' => 'L’URL qu’avètz indicaa es pas valida.',
	'form_pet_votre_email' => 'Vòstra adreiça e-mail',
	'form_pet_votre_nom' => 'Vòstre nom o pseudonim', # MODIF
	'form_pet_votre_site' => 'Se tenètz un sit, o poètz marcar çai sos',

	// I
	'info_adresse_email' => 'ADREIÇA E-MAIL:',
	'info_site_web' => 'SIT WEB:',

	// L
	'lien_reponse_article' => 'Respònsa a l’article'
);

?>
